@@ -4,7 +4,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # -------------------------------------
 
@@ -170,6 +170,14 @@ For additional information, see the documentation for these modules:
   Test::Reporter
   CPAN::YACSmoke
 
+=head1 DSLIP
+
+  b - Beta testing
+  d - Developer
+  p - Perl-only
+  O - Object oriented
+  p - Standard-Perl: user may choose between GPL and Artistic
+
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
